# Cursed Screen

This is a library for buffered terminal output.

## Installation

```bash
$ composer require cursed/screen
```

## Usage

Creating a `Screen` instance will switch to the alternate buffer and initialize the terminal to a known state.

```php
$screen = new Cursed\Screen();
// Write some output
$screen->writeAt(0,0,"I'm in the top left corner");
$screen->writeAt(0,-1,"I'm in the bottom left corner");
// Remember to flush when you're done
$screen->flush();

// you should wait here, in a loop or using readline or whatever, destroying
// the $screen object will restore the terminal to the primary buffer and
// previous state.
```

### Renderables

Renderables are useful.

```php
class StatusBar implements Renderable {
    public function render(Screen $screen, array $options = []): void {
        $screen->writeAt(0,-1,"\e[30;47m {$options['text']}\e[K\e[0m");
    }
}

$statusbar = new StatusBar();
$screen->draw($statusbar, [ 'text' => "Hello World" ]);

```

### Handling resize

To deal with the terminal window being resized, you need to listen for the `SIGWINCH` signal and then triggering a re-measure and a re-draw.

```php
pcntl_signal(SIGWINCH, function () use ($screen) {
    // Update the line and column count
    $screen->measureTerminal();
    // Call on your own code to redraw
    yourRedrawFunc($screen->lines, $screen->columns);
});

// Remember to dispatch signals in your main loop
pcntl_signal_dispatch();
```
