<?php

namespace Cursed\Screen\Component;

use Cursed\Screen\Renderable;
use Cursed\Screen\Screen;

/**
 * Tab component
 * 
 * This is a renderable dual-purpose component. Firstly it is added to the TabStrip 
 * to provide labels and stuff, and secondly it can be rendered to display the actua
 * tab contents.
 * 
 * 
 */
class Tab implements Renderable
{
    public function __construct(
        public string $label,
        public ?Renderable $renderable = null,
        public mixed $renderFunc = null,
        public array $hotkeys = [],
    )
    {
    }

    public function render(Screen $screen, array $options = []): void
    {
        if ($this->renderable) {
            $screen->draw($this->renderable, $options);
        }
        if (is_callable($this->renderFunc)) {
            call_user_func($this->renderFunc, $screen, $options);
        }
    }

    public function hotkeys(): array
    {
        return $this->hotkeys;
    }
}
