<?php

namespace Cursed\Screen\Component;

use Cursed\Screen\Renderable;
use Cursed\Screen\Screen;

class TabStrip implements Renderable
{
    const LEFT_SLOPE  = "\u{2571}";
    const LEFT_EDGE   = "\u{25e2}";
    const RIGHT_SLOPE = "\u{2572}";
    const RIGHT_EDGE  = "\u{25e3}";
    const RIGHT_TAIL  = "\u{25e5}";
    const BOTTOM_EDGE  = "\u{2581}";

    private int $current = 0;

    private $tabs = [];

    public function addTab(Tab $tab, ?string $id = null): self
    {
        $id ??= uniqid("tab");
        $this->tabs[$id] = $tab;
        return $this;
    }

    public function countTabs(): int
    {
        return count($this->tabs);
    }

    public function setCurrent(int $index): self
    {
        $this->current = max(0, min($index, count($this->tabs) - 1));

        return $this;
    }

    public function getCurrent(): int
    {
        return $this->current;
    }

    public function getTab(): Tab
    {
        return array_values($this->tabs)[$this->current];
    }

    public function getTabs(): array
    {
        return $this->tabs;
    }

    public function render(Screen $screen, array $options = []): void
    {
        $screen
            ->writeAt(0, 0, "\e[0;90m".str_repeat(self::BOTTOM_EDGE, $screen->columns))
            ->setCursorPosition(1, 0);
        $index = 0;
        foreach ($this->tabs as $id=>$tab) {
            if ($index == $this->current) {
                $screen
                    ->write("\e[0;34m".self::LEFT_EDGE)
                    ->write("\e[0;44;97;1m ".$tab->label." \e[0m")
                    ->write("\e[0;34m".self::RIGHT_EDGE);
            } else {
                $screen
                    ->write("\e[0;90m".self::LEFT_EDGE)
                    ->write("\e[0;37;2;100m ".$tab->label." \e[0m")
                    ->write("\e[0;90m".self::RIGHT_EDGE);
            }
            $index++;
        }
    }
}
